# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot.display import is_point_on_any_screen
from autopilot.exceptions import StateNotFoundError

from ubuntu_system_tests.helpers.autopilot.object import (
    _get_y_and_x, _get_x_and_y)


def order_by_x_coord(object_list, include_off_screen=False):
    """
    Return an ordered list of objects ordered by x co-ordinate first
    and then y co-ordinate second if x co-ordinates match.

    :param object_list: List of objects containing globalRect property.
    :param include_off_screen: Whether to include objects that are not within
                               the bounds of any screen.
    :return: List of sorted objects.

    """
    return _order_by_key(object_list, _get_x_and_y, include_off_screen)


def _order_by_key(object_list, sort_key, include_off_screen):
    """
    Return an ordered list of objects ordered by key.

    :param object_list: List of objects containing globalRect property.
    :param sort_key: Sorting key to use.
    :param include_off_screen: Whether to include objects that are not within
                               the bounds of any screen.
    :return: List of sorted objects.

    """
    objects = []
    for obj in object_list:
        try:
            # If obj is no longer valid this can cause excpetion
            point = obj.globalRect.x, obj.globalRect.y
            if include_off_screen:
                objects.append(obj)
            elif is_point_on_any_screen(point):
                objects.append(obj)
        except StateNotFoundError:
            pass
    return sorted(objects, key=sort_key)


def order_by_y_coord(object_list, include_off_screen=False):
    """
    Return an ordered list of objects ordered by y co-ordinate first
    and then x co-ordinate second if y co-ordinates match.

    :param object_list: List of objects containing globalRect property.
    :param include_off_screen: Whether to include objects that are not within
                               the bounds of any screen.
    :return: List of sorted objects.

    """
    return _order_by_key(object_list, _get_y_and_x, include_off_screen)
