# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import close_app
from ubuntu_system_tests.helpers import wait_until


APP_NAME = 'Calculator'
APP_WIN_ID = 'com.ubuntu.calculator_calculator'
QML = 'ubuntu-calculator-app'


def launch_calculator_app():
    """
    Launch calculator app from apps scope and return its proxy object.
    """
    launch_application_from_apps_scope(APP_NAME)
    wait_until(is_calculator_app_running, period=0.5)
    return get_calculator_app_proxy()


def close_calculator_app():
    """ Close the calculator app using task switcher """
    if is_calculator_app_running():
        close_app(APP_WIN_ID)


def is_calculator_app_running():
    """ Indicate if the calculator app is currently running """
    return processes.is_qmlscene_running_with_qmlfile(QML)


def get_calculator_app_proxy():
    """Return the proxy object of the calculator app."""
    from ubuntu_system_tests.helpers.calculator import _cpo  # NOQA
    proxy = autopilot.get_proxy_object_for_existing_qmlscene_process(QML)
    return proxy.main_view
