# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from json import (load, JSONDecoder)
from os import path, walk

from ubuntu_system_tests.helpers import AttrDict
from ubuntu_system_tests.helpers import file_system as fs


_full_dict = AttrDict()


class AttrDictDecoder(JSONDecoder):
    """ Class used to decode a dict into a AttrDict object """

    def __init__(self, *args, **kargs):
        JSONDecoder.__init__(self, object_hook=dict_to_attr_dict)


def _get_metadata_file(dir):
    """ Retrieve the metadata file path from a dir, in case there is not one
    return None """
    file = path.join(dir, 'metadata.json')
    if not path.isfile(file):
        return None
    return file


def dict_to_attr_dict(d):
    try:
        return AttrDict(**d)
    except:
        return d


def _load_metadata(dir):
    """ Load the metadata object from an specific dir """
    file = _get_metadata_file(dir)

    if file:
        with open(file) as data_file:
            return load(data_file, cls=AttrDictDecoder)
    else:
        return AttrDict()


def _load_metadata_list(parent):
    """ Load the metadata object from a list of dirs """
    all_dict = AttrDict()
    for root, dirs, files in walk(parent):
        for dir in dirs:
            subdict = _load_metadata(path.join(parent, dir))
            if subdict:
                all_dict[dir] = subdict

    return all_dict


def load_test_metadata():
    """ Load all the metadata objects from the test data dir. The test metadata
    is loaded just the first time fron the metadata.json files and it is stored
    internally for faster access"""
    global _full_dict
    if _full_dict:
        return _full_dict

    _full_dict = _load_metadata_list(fs.DIR_TEST_DATA)
    return _full_dict
