# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import subprocess

from ubuntu_system_tests.helpers import device


def _get_display_metadata():
    """Return display metadata for device."""
    return device.get_current_device_metadata().display


def get_current_brightness():
    """Return the current brightness from the backlight driver."""
    display = _get_display_metadata()
    output = subprocess.check_output(
        ['cat', display.brightness], universal_newlines=True)
    return int(output.strip())


def get_max_brightness_level():
    """Return maximum defined brightness level for device."""
    return _get_display_metadata().brightness_max


def get_min_brightness_level():
    """Return minimum defined brightness level for device."""
    return _get_display_metadata().brightness_min


def is_display_on():
    """Return True if display is turned on, False otherwise."""
    return get_current_brightness() > 0


def is_display_off():
    """Return True if display is turned off, False otherwise."""
    return not is_display_on()
