# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import os
import shutil

from ubuntu_system_tests.helpers.backup_restore_fixture import (
    BackupRestoreFixture)

from ubuntu_system_tests.helpers.file_system import(
    DIR_HOME_CACHE_GALLERY,
    DIR_HOME_CAMERA_PICTURES,
    DIR_TEST_DATA_IMAGES,
    create_directory_if_not_exists,
    delete_file,
)


class GalleryTestEnvironment(fixtures.Fixture):
    """Fixture to put a sample image file in pictures directory."""

    SAMPLE_FILE = "sample01.jpg"

    def __init__(self, sample_file_name=SAMPLE_FILE):
        self.sample_file_name = sample_file_name

    def setUp(self):
        super(GalleryTestEnvironment, self).setUp()
        self._copy_sample_file_to_camera_directory(self.sample_file_name)

    def _copy_sample_file_to_camera_directory(self, file_name):
        """
        Puts the given file in photos directory

        :param file_name: name of the file to copy
        """
        file_path = os.path.abspath(os.path.join(DIR_TEST_DATA_IMAGES,
                                                 file_name))
        if os.path.exists(file_path):
            create_directory_if_not_exists(DIR_HOME_CAMERA_PICTURES)
            shutil.copy(file_path, DIR_HOME_CAMERA_PICTURES)
            self.addCleanup(delete_file,
                            os.path.join(DIR_HOME_CAMERA_PICTURES, file_name))


class BackupRestoreGalleryData(fixtures.Fixture):
    """Generic fixture class to backup and restore gallery cache data."""

    def __init__(self, start_clean=True):
        """
        :param start_clean: Whether to clean media directories after backup.

        """
        self.start_clean = start_clean

    def setUp(self):
        """Backup the required directory and register restore actions."""
        super().setUp()
        self._backup_files()

    def _backup_files(self):
        """Backup the files which are removed during testing."""
        self.useFixture(BackupRestoreFixture(
            DIR_HOME_CACHE_GALLERY, start_clean=self.start_clean))
