# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntu_system_tests.helpers.ubuntuuitoolkit import slider
from ubuntu_system_tests.helpers.indicators import(
    IndicatorPage,
    INDICATOR_PAGE_PATH
)
from ubuntu_system_tests.helpers.autopilot import(
    validate_dbus_object,
    click_object
)
from ubuntu_system_tests.helpers import unity8


class BatteryIndicatorPage(IndicatorPage):
    """Autopilot helper for the battery indicator page."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, unity8.UNITY8_PATH_ROOT, INDICATOR_PAGE_PATH,
            objectName='indicator-power-page')

    def _get_battery_settings_menu_item(self):
        """Return the battery settings list item."""
        return self.select_single(
            'StandardMenu',
            objectName='indicator.activate-phone-settings')

    @click_object
    def open_battery_settings(self):
        """Tap the battery settings menu item to open settings."""
        return self._get_battery_settings_menu_item()

    def get_brightness_slider_widget(self):
        """Return the slider widget on the battery indicator page."""
        return self.select_single(slider.Slider, objectName='slider')

    def get_current_brightness(self):
        return float(self.get_brightness_slider_widget().value)

    def _get_brightness_switch(self):
        """Return the auto brightness switch."""
        return self.select_single('SwitchMenu',
                                  objectName='indicator.auto-brightness')

    @click_object
    def click_brightness_switch(self):
        return self._get_brightness_switch()

    def enable_auto_brightness(self):
        """Enable auto brightness."""
        if not self._get_brightness_switch().checked:
            self.click_brightness_switch()

    def disable_auto_brightness(self):
        """Disable auto brightness."""
        if self._get_brightness_switch().checked:
            self.click_brightness_switch()
