# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import ubuntuuitoolkit

from ubuntu_system_tests.helpers.autopilot import(
    validate_dbus_object,
    patched_wait_select_single,
    click_object,
)

APP_PATH_ROOT = b'comubuntumusic'


class MusicApp(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
    """Autopilot helper object for Music app."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, APP_PATH_ROOT)

    @property
    def main_view(self):
        return patched_wait_select_single(
            root=self, class_object=MainView, class_name='MainView',
            objectName='musicMainView')


class MainView(ubuntuuitoolkit.MainView):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'MainView',
            objectName='musicMainView')

    def walkthrough_page(self):
        return self.wait_select_single(Walkthrough,
                                       objectName="walkthroughPage")

    def ensure_walkthrough_page_not_visible(self):
        walkthrough_page = self.walkthrough_page()
        if walkthrough_page.visible:
            walkthrough_page.skip()

    def get_songs_page(self):
        """Switch to songs tab and return its view."""
        self.switch_to_tab('songsTab')
        return self.wait_select_single(Songs, objectName='songsPage')


class Page(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
    """Autopilot helper for Pages."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        # Base class that should never be instantiated directly
        return False

    @property
    def main_view(self):
        return patched_wait_select_single(
            root=self.get_root_instance(), class_object=MainView,
            class_name='MainView', objectName='musicMainView')


class Songs(Page):
    """ Autopilot helper for the tracks page """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'Songs', objectName='songsPage')

    def get_track(self, i):
        """Get a track list item by index number."""
        return self.wait_select_single(
            objectName="tracksPageListItem" + str(i))

    @click_object
    def _tap_track_to_play(self, i):
        return self.get_track(i)

    def play_track(self, i):
        self._tap_track_to_play(i)
        return self.main_view.wait_select_single(NowPlaying)


class NowPlaying(Page):
    """ Autopilot helper for now playing page """
    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(path, state, APP_PATH_ROOT, b'NowPlaying',
                                    objectName='nowPlayingPage')

    @property
    def player(self):
        return self.main_view.wait_select_single(Player)

    def _get_play_button(self):
        return self.wait_select_single(objectName="playShape")

    @click_object
    def click_play_button(self):
        return self._get_play_button()

    def get_artist(self):
        return self.select_single(objectName='artistLabel').text

    def get_title(self):
        return self.select_single(objectName='playercontroltitle').text


class Player(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'Player', objectName='player')

    @property
    def title(self):
        return self.get_current_meta().title

    @property
    def artist(self):
        return self.get_current_meta().author

    def get_current_meta(self):
        return self.select_single(objectName="currentMeta")


class Walkthrough(Page):
    """ Autopilot helper for the walkthrough page """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(path, state, APP_PATH_ROOT, b'Walkthrough',
                                    objectName='walkthroughPage')

    @click_object
    def skip(self):
        """Press the skip button to skip the wizard."""
        return self.wait_select_single("UCLabel", objectName="skipLabel")
