# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import autopilot
import logging

from ubuntu_system_tests.helpers.notifications import NotificationBase

logger = logging.getLogger(__name__)

BUTTON_OK = 'OK'
BUTTON_SNOOZE = 'Snooze'
BUTTONS = [BUTTON_OK, BUTTON_SNOOZE]


def validate(notification):
    """
    Return True if notification object is valid and looks like an alarm
    notification.

    Note this is implemented as a static method because it is reliable
    in cases where multiple notifications are displayed and autopilot CPO
    inheritance fails.

    :param notification: The notification object to validate.

    """
    if notification and isinstance(notification, Notification):
        try:
            return (notification.validate_buttons(BUTTONS) and
                    notification.summary.startswith('Alarm'))
        except autopilot.exceptions.StateNotFoundError:
            pass
    return False


class Notification(NotificationBase):

    def get_ok_button(self):
        return self.get_button(text=BUTTON_OK, objectName='notify_button0')

    def get_snooze_button(self):
        return self.get_button(text=BUTTON_SNOOZE, objectName='notify_button1')

    @autopilot.logging.log_action(logger.info)
    def dismiss(self):
        self.pointing_device.click_object(self.get_ok_button())

    @autopilot.logging.log_action(logger.info)
    def snooze(self):
        self.pointing_device.click_object(self.get_snooze_button())
