# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import autopilot
import ubuntuuitoolkit as uitk

from autopilot.input._common import get_center_point

logger = logging.getLogger(__name__)


class SwipeToAct(uitk.UbuntuUIToolkitCustomProxyObjectBase):

    """Class to represent left or right action slider."""

    @autopilot.logging.log_action(logger.info)
    def swipe_to_left(self):
        self._swipe(self._get_slider(), self._get_left_edge())

    @autopilot.logging.log_action(logger.info)
    def swipe_to_right(self):
        self._swipe(self._get_slider(), self._get_right_edge())

    @autopilot.logging.log_action(logger.info)
    def _swipe(self, from_, to_x):
        center_x, center_y = get_center_point(from_)
        self.pointing_device.drag(center_x, center_y, to_x, center_y)

    def _get_slider(self):
        return self.select_single('UCUbuntuShape', objectName='slider')

    def _get_left_edge(self):
        return self.globalRect[0]

    def _get_right_edge(self):
        return self.globalRect[0] + self.width
