
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import dbus

import fixtures


class RadioKillswitch(fixtures.Fixture):

    """Autopilot helper representing URfkill D-Bus object."""

    def __init__(self, expected_state):
        super().setUp()
        self.expected_state = expected_state

    def setUp(self):
        super().setUp()
        bus = dbus.SystemBus()
        proxy = bus.get_object(
            bus_name='org.freedesktop.URfkill',
            object_path='/org/freedesktop/URfkill')
        self._urfkill = dbus.Interface(
            proxy,
            'org.freedesktop.URfkill')
        self.initial_state = self.is_flight_mode_on()
        self.addCleanup(self.set_flight_mode, self.initial_state)
        self.set_flight_mode(self.expected_state)

    def is_flight_mode_on(self):
        """Return True if flight mode is on, False otherwise.

        indicator-network syncs with URfkill to implement flight mode.

        """
        return self._urfkill.IsFlightMode()

    def set_flight_mode(self, state):
        """Set flight mode to the given state: True for on, False for off.

        Only re-set if necessary; note that we use the indicator
        action to set to off as we don't necessarily have polkit perms
        to set via URfkill.

        """
        current_state = self.is_flight_mode_on()
        if state and not current_state:
            self._urfkill.FlightMode(True)
        elif not state and current_state:
            _toggle_indicator_network_airplane_mode()


def _toggle_indicator_network_airplane_mode():
    """Activate indicator-network's 'airplane-enabled' action.

    We go behind the UI to toggle--use only as a last resort when
    re-setting the initial state, e.g.

    """
    bus = dbus.SessionBus()
    proxy = bus.get_object(bus_name='com.canonical.indicator.network',
                           object_path='/com/canonical/indicator/network')
    interface = dbus.Interface(proxy, 'org.gtk.Actions')
    interface.Activate('airplane.enabled', [], {})
