# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import time

from autopilot import exceptions


from ubuntu_system_tests.helpers import wait_until
from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.scopes.music import _preview
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class Preview(_preview.Preview):
    """
    This class represents the preview screen that is part of the
    GenericScopeView and implement the methods specific to the track Preview.

    """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'Preview',
            objectName='preview')

    def get_play_button(self):
        """ Retrieve the play button once it is not moving any more """
        button = self.wait_select_single(objectName='playButton',
                                         visible=True)
        for i in range(10):
            (x, y, w, h) = button.globalRect
            time.sleep(0.2)
            if (x, y, w, h) == button.globalRect:
                return button
        return button

    def play(self):
        """ Click on the play button and wait until the progress var is
        displayed """
        play_button = self.get_play_button()
        self.pointing_device.click_object(play_button)
        self.get_progress_bar().visible.wait_for(True)

    def get_progress_bar(self):
        return self.select_single(objectName='progressBarFill')

    def is_progress_bar_moving(self):
        """ Indicates if the progress bar is moving forward. This process will
        wait half second to see if the progress was has moved """
        try:
            first = self.get_progress_bar().width
            return wait_until(lambda: self.get_progress_bar().width > first,
                              timeout=5, period=1)
        except exceptions.StateNotFoundError:
            return False

    def pause(self):
        """ Pause the song """
        self.pointing_device.click_object(self.get_play_button())

    def play_in_music_app(self):
        """ Play the song in the music-app """
        self.click_not_moving(self.wait_select_single(objectName='buttonplay'))
