# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase

from ubuntu_system_tests.helpers.autopilot import (
    is_element, validate_dbus_object)
from ubuntu_system_tests.helpers.autopilot.list import order_by_x_coord
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class DashCategoryBase(UbuntuUIToolkitCustomProxyObjectBase):
    """This class represent the Dash Category Base."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'DashCategoryBase')

    def get_see_all(self):
        """ Retrieve the "see all" button """
        return self.select_single('UCLabel', text='See all', visible=True)

    def get_see_less(self):
        """ Retrieve the "see less" button """
        return self.select_single('UCLabel', text='See less', visible=True)

    def get_pictures_list(self):
        """ Retrieve all the pictures displayed currently in the list """
        imgs = self.select_many(type_name='CroppedImageMinimumSourceSize',
                                objectName='artImage')
        return order_by_x_coord(imgs, include_off_screen=True)

    def is_see_all_displayed(self):
        """ Indicate if there is at least a button with text "See all" """
        return is_element(self.get_see_all)

    def is_see_less_displayed(self):
        """ Indicate if there is at least a button with text "See less" """
        return is_element(self.get_see_less)

    def is_not_see_less_displayed(self):
        """ Indicate if there are not any "See less" button being displayed """
        return not self.is_see_less_displayed()

    def get_grid(self):
        return self.select_single('QQuickGridView', visible=True)
