# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntuuitoolkit import QQuickFlickable

from ubuntu_system_tests.helpers.autopilot import (
    patched_wait_select_single, validate_dbus_object)
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class ListViewWithPageHeader(QQuickFlickable):
    """This class represent the Photos List View."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'ListViewWithPageHeader')

    def get_today_category(self):
        """ Get the today category section """
        from ubuntu_system_tests.helpers.scopes.photos import _category
        return patched_wait_select_single(
            root=self, class_object=_category.DashCategoryBase,
            class_name='DashCategoryBase', objectName='dashCategorytoday',
            visible=True)

    def see_all(self, category):
        """ Click on the see all button displayed in the selected position """
        see_all = category.get_see_all()
        self.swipe_child_into_view(see_all)
        self.pointing_device.click_object(see_all)
        category.get_grid().moving.wait_for(False)

    def see_less(self, category):
        """ Click on the see less button displayed in the selected position """
        see_less = category.get_see_less()
        self.swipe_child_into_view(see_less)
        self.pointing_device.click_object(see_less)
        category.get_grid().moving.wait_for(False)
