# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ubuntuuitoolkit as uitk

from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class Preview(uitk.UbuntuUIToolkitCustomProxyObjectBase):
    """
    This class represents the preview Widget that is part of the
    GenericScopeView and implement the methods specific to the Video
    Preview.
    """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'Preview')

    def _get_current(self, objname):
        return self.select_single('PreviewWidget', objectName=objname)

    def get_statistics(self):
        """ Retrieve a string with the likes and dislikes """
        list_view = self.select_single('QQuickListView', visible=True)
        if not list_view.atYEnd:
            list_view.swipe_to_bottom()
        statistics = self._get_current('statistics')
        stat_text = statistics.select_single(objectName='titleLabel').text
        if not list_view.atYBeginning:
            list_view.swipe_to_top()
        return stat_text

    def get_summary(self):
        """ Retrieve the summary displayed """
        summary = self._get_current('summary')
        return summary.select_single(objectName='textLabel').text

    def get_title(self):
        return self._get_subheader().title

    def get_subtitle(self):
        return self._get_subheader().subtitle

    def _get_subheader(self):
        """ Retrieve a pair with the title and subtitle displayed """
        header = self._get_current('header')
        return header.select_single(objectName='innerPreviewHeader')

    def _get_video(self):
        return self._get_current('video')

    def play_video(self):
        """
        Click on the play button to start the video playback in the webbrowser
        """
        video = self._get_video()
        play = video.wait_select_single(
            objectName='playButton', visible=True, enabled=True)
        self.pointing_device.click_object(play)

    def get_thumbnail(self):
        """ Retrieve the thumbnail url for the current video """
        video = self._get_video()
        thumbnail = video.select_single(objectName='screenshot')
        return thumbnail.source

    def get_external_id(self):
        """ Retrieve the id used to link to the external video """
        video = self._get_video()
        screenshot = video.select_single(objectName='screenshot')
        return screenshot.source.split('/')[-2]
