# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from datetime import datetime

from ubuntu_system_tests.helpers import context

start_times = {}

LAUNCH_ID = 'launch'


def start(id):
    """ Start the timer identified with the id when it has being enabled """
    if id in context.shared.timers:
        global start_times
        start_times[id] = datetime.now()


def _get_elapsed_time(id):
    global start_times
    end_time = datetime.now()
    if id not in start_times:
        raise RuntimeError('Timer with id {} not initialized'.format(id))

    elapsed_time = end_time - start_times[id]
    return elapsed_time.total_seconds()


def stop(id):
    """ Retrieve the elapsed time in seconds from the id was started and stop
    the counter """
    elapsed_time = _get_elapsed_time(id)
    start_times.pop(id)
    return elapsed_time


def get_elaspsed_time(id):
    """ Retrieve the elapsed time in seconds from the id was started """
    return _get_elapsed_time(id)
