# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ubuntuuitoolkit

from ubuntu_system_tests.helpers.autopilot import (
    is_element, validate_dbus_object)

APP_PATH_ROOT = b'maliit-server'


class MaliitServer(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, APP_PATH_ROOT)

    @property
    def keyboard(self):
        return self.wait_select_single(Keyboard,
                                       objectName='fullScreenItem')


class Keyboard(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'Keyboard',
            objectName='fullScreenItem')

    @property
    def word_ribbon_list(self):
        return self.wait_select_single(QQuickListView,
                                       objectName='wordListView')


class QQuickListView(ubuntuuitoolkit.QQuickListView):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'QQuickListView',
            objectName='wordListView')

    def _get_highlighted_item(self):
        """Return the item on the word ribbon with bold text."""
        return self.wait_select_single(textBold=True)

    def is_text_bold(self, text):
        """
        Return bool, representing if the requested text is appearing bold in
        the ribbon
        """
        item = self._get_highlighted_item()
        return is_element(item.select_single, text=text)

    def tap_suggested_word(self, text):
        """Tap on the requested text in the words ribbon."""
        self.pointing_device.click_object(self.wait_select_single(text=text))

    def _get_all_suggested_words(self):
        return self.select_many(
            baseUrl='file:///usr/share/maliit/plugins/com/ubuntu/'
                    'WordRibbon.qml',
            visible=True
        )

    def get_suggested_words(self):
        """Returns a list of suggested words in the ribbon."""
        return [item.text for item in self._get_all_suggested_words()]

    def is_suggestions_list_empty(self):
        """Return True if suggestions list is empty otherwise return False."""
        items = self.get_suggested_words()
        if len(items) == 0:
            return True
        elif len(items) == 1:
            return items[0] == ''
        return False
