# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from selenium.webdriver.support.ui import WebDriverWait

from ubuntu_system_tests.helpers.unity8 import close_app
from ubuntu_system_tests.helpers import webapp
from ubuntu_system_tests.helpers.webapp import BasePage

WEBAPP_NAME = 'eBay'
WEBAPP_PACKAGE = 'com.ubuntu.developer.webapps.webapp-ebay'
WEBAPP_WIN_ID = 'com.ubuntu.developer.webapps.webapp-ebay_webapp-ebay'


def launch_ebay_webapp():
    """ Launch the Ebay webapp from apps scope and return its proxy object
    """
    return webapp.launch_webapp(WEBAPP_NAME, WEBAPP_PACKAGE)


def close_ebay_webapp():
    """ Close the ebay webapp using task switcher """
    if is_ebay_webapp_running():
        close_app(WEBAPP_WIN_ID)


def is_ebay_webapp_running():
    """ Indicate if the ebay webapp is currently running """
    return webapp.is_webapp_runing(WEBAPP_PACKAGE)


class Homepage(BasePage):
    _search_box_id = 'kw'

    def search_for(self, term):
        search_field = self.driver.find_element_by_id(self._search_box_id)
        search_field.clear()
        script = "document.getElementById(""'{}').setAttribute('value', '{}')".format(  # NOQA
            self._search_box_id, term)
        self.driver.execute_script(script)
        search_field.submit()
        return SearchResults(self.driver)


class SearchResults(BasePage):
    _product_list_css = 'div.itemDiv pre.preTxt'

    def results_count(self):
        # the default wait isn't enough sometimes
        WebDriverWait(self.driver, 100).until(
            lambda driver: driver.find_element_by_css_selector(
                self._product_list_css))

        results = self.driver.find_elements_by_css_selector(
            self._product_list_css)
        return len(results)
