# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import re

from selenium.common.exceptions import TimeoutException
from selenium.webdriver.common.by import By
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.support.ui import WebDriverWait

from ubuntu_system_tests.helpers.unity8 import close_app
from ubuntu_system_tests.helpers import webapp
from ubuntu_system_tests.helpers.webapp import BasePage

WEBAPP_NAME = 'HERE Maps'
WEBAPP_PACKAGE = 'com.nokia.heremaps'
WEBAPP_WIN_ID = 'com.nokia.heremaps_here'


def launch_here_webapp():
    """ Launch the Here webapp from apps scope and return its proxy object
    """
    return webapp.launch_webapp(WEBAPP_NAME, WEBAPP_PACKAGE)


def close_here_webapp():
    """ Close the here webapp using task switcher """
    if is_here_webapp_running():
        close_app(WEBAPP_WIN_ID)


def is_here_webapp_running():
    """ Indicate if the here webapp is currently running """
    webapp_package = WEBAPP_PACKAGE
    return webapp.is_webapp_runing(webapp_package)


class Homepage(BasePage):
    _my_location = "//a[@class='mh5_Button position available']"
    _tracking = "//a[@class='mh5_Button position available tracking']"
    _map_canvas = "//*[@class='mh5_mapContainer']/canvas"

    def go_to_my_location(self):
        """ Click on my location button and wait until the location detected or
        the timeout is reached. In case of timeout, click again in the location
        button.
        """
        button = self.driver.find_element(By.XPATH, self._my_location)
        self.tap(button)

        # After my location button is selected the location button has to be
        # in tracking mode
        button = self.driver.find_element(By.XPATH, self._tracking)

        # Wait until my location is detected and the map displays the current
        # location
        try:
            WebDriverWait(self.driver, 30).until(
                EC.invisibility_of_element_located((By.XPATH, self._tracking)))
        except TimeoutException:
            self.tap(button)

    def select_map_position(self, x, y):
        """ Select a place in the position selected by clicking and holding on
        the map
        """
        self.tap_and_hold(x, y, 0.5)

    def get_map_size(self):
        """ Get the map size (width, height) based on the map style """

        elem = self.driver.find_element(By.XPATH, self._map_canvas)
        sizes = elem.get_attribute('style').split(';')

        width = int(re.search('width: (.+)px', sizes[0]).group(1))
        height = int(re.search('height: (.+)px', sizes[1]).group(1))

        return width, height
