# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015-2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import (
    close_app, launch_application_from_launcher
)

APP = 'webbrowser-app'
APP_NAME = 'Browser'
APP_WIN_ID = 'webbrowser-app'


def launch_webbrowser_app():
    """
    Launch the webbrowser app from apps scope and return proxy object.

    :return: Proxy object for webbrowser application.

    """
    launch_application_from_apps_scope(APP_NAME)
    return get_webbrowser_app_proxy()


def close_webbrowser_app():
    """ Close the webbrowser app using task switcher """
    if is_webbrowser_app_running():
        close_app(APP_WIN_ID)


def is_webbrowser_app_running():
    """ Indicate if the webbrowser app is currently running """
    return processes.is_process_running(APP)


def get_webbrowser_app_proxy():
    """
    Return webbrowser app proxy object from existing process.

    :return: Proxy object for webbrowser application.

    """
    from ubuntu_system_tests.helpers.webbrowser import _cpo  # NOQA
    proxy = autopilot.get_proxy_object_for_existing_app(APP)
    return proxy.main_window


def launch_webbrowser_from_launcher():
    """Start webbrowser from the launcher."""
    launch_application_from_launcher(APP_WIN_ID)
    return get_webbrowser_app_proxy()


def get_webbrowser_process_id():
    """ Retrieve the webbrowser process id """
    return processes.get_process_id(APP)
