# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import scopes
from ubuntu_system_tests.helpers.scopes import apps, go_to_apps_scope
from ubuntu_system_tests.tests.scopes import BaseScopeTestCase


class AppsScopeTest(BaseScopeTestCase):
    """Tests for the Apps scope."""

    def test_search_apps_scope(self):
        """
        Test to search the apps scope.
        1) Search the apps scope for an app that is not installed on device.
        2) Check that app is not listed in search results.
        3) Open the app store.
        4) Check that the app can be found in the app store.
        5) Return to Apps scope and search for an app that is installed on
           the device.
        6) Check the app is listed in search results and return to app scope.

        """
        installed_app = 'Contacts'
        not_installed_app = 'OSMTouch'

        scope_data = scopes.get_scope_data(scopes.SCOPE_ID_APPS)
        apps_scope = go_to_apps_scope()
        apps_scope.search(not_installed_app)
        self.assertFalse(apps_scope.is_app_displayed(not_installed_app))
        self.assertTrue(apps_scope.is_app_displayed(apps.APP_STORE_TITLE))

        apps_scope.go_to_store()
        self.assertTrue(apps_scope.is_app_displayed(not_installed_app))

        self._go_back_and_validate_header_title(apps.APP_STORE_TITLE)
        self._go_back_and_validate_header_title(scope_data.title)

        apps_scope.search(installed_app)
        self.assertTrue(apps_scope.is_app_displayed(installed_app))
        self.assertTrue(apps_scope.is_app_displayed(apps.APP_STORE_TITLE))

        self._go_back_and_validate_header_title(scope_data.title)
