# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.helpers.location.coordinates import EIFFEL_TOWER
from ubuntu_system_tests.helpers.location.fixture_setup import (
    DummyLocation,
    SetLocationAccessRequests
)
from ubuntu_system_tests.tests import base_webbrowser

APP = 'webbrowser-app'
MAPS_URL = 'http://maps.google.com'


class LocationWithBrowserTestCase(base_webbrowser.WebBrowserBase):

    def setUp(self):
        self.useFixture(DummyLocation(*EIFFEL_TOWER))
        self.useFixture(SetLocationAccessRequests(APP))
        super().setUp()

    def _get_longitude_from_google_maps_url(self):
        """Parse the provided url to scrap the current coordinates."""
        url = self._get_current_url()
        parsed_coordinates = url.split('@')[1].split(',')
        return parsed_coordinates[1]

    def test_location_fix_with_google_maps(self):
        """
        Prerequisite: Location detection and GPS enabled and a data connection
        (WiFi or cellular) must be available.
        1. Open the Browser app and type in 'maps.google.com'
           - Web browser opens
           - Location permission dialog appears
        2. Press the 'Allow' button
           Google maps loads with the current location of the fix
        """
        self.browser.open_page_and_accept_location_permission_prompt(
            MAPS_URL)
        # We are only verifying the longitude right now as there was apparently
        # no way to query the "correct" latitude from the google maps url
        # or the page itself.
        self.assertThat(lambda: self._get_longitude_from_google_maps_url(),
                        Eventually(Equals(EIFFEL_TOWER[1])))
