# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import autopilot
from autopilot.matchers import Eventually
from testtools.matchers import Equals
from testtools import skipUnless

from ubuntu_system_tests.helpers import ofono
from ubuntu_system_tests.helpers.ofono import fixture_setup as ofono_fixture
from ubuntu_system_tests.helpers import system_settings
from ubuntu_system_tests.tests import base


class SimPinTestCase(base.BaseUbuntuSystemTestCase):

    @skipUnless(ofono.is_sim_inserted(sim_number=0),
                'No SIM inserted in slot 0')
    def setUp(self):
        super(SimPinTestCase, self).setUp()
        self.useFixture(ofono_fixture.UnlockSims())

        self.unity_proxy = self.restart_unity()
        self.app = system_settings.launch_system_settings()

        # As per this bug where we're unable to launch the browser from the
        # scope after a unity8 reboot.
        # https://bugs.launchpad.net/ubuntu/+source/unity8/+bug/1401361
        self.unity_proxy.ensure_app_loaded()
        self.sim_pin = autopilot.get_test_configuration()['sim_0_pin']

    def test_sim_pin_lock_and_unlock(self):
        """SIM PIN lock must respond to setting."""
        self.security_page = self.app.go_to_security_page()
        self.sim_number = 0
        self.assertFalse(
            ofono.is_pin_locked(self.sim_number),
            msg='SIM must be unlocked before testing!'
        )

        sim_pin_page = self.security_page.go_to_sim_lock()
        sim_pin_page.click_sim_pin_switch(self.sim_number)
        sim_pin_page.enter_lock_pin(self.sim_pin)
        switch = sim_pin_page.get_sim_pin_switch(self.sim_number)
        self.assertThat(switch.checked, Eventually(Equals(True)))
        self.assertThat(
            lambda: ofono.is_pin_locked(self.sim_number),
            Eventually(Equals(True))
        )
        sim_pin_page.click_sim_pin_switch(self.sim_number)
        sim_pin_page.enter_lock_pin(self.sim_pin)
        self.assertThat(switch.checked, Eventually(Equals(False)))
        self.assertThat(
            lambda: ofono.is_pin_locked(self.sim_number),
            Eventually(Equals(False))
        )
